@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Dist::Zilla::PluginBundle::MITHALDU;
-our $VERSION = '1.190320'; # VERSION
+our $VERSION = '1.190321'; # VERSION
 
 # Dependencies
 use autodie 2.00;
@@ -197,7 +197,7 @@ sub configure {
   $version_provider = [ 'AutoVersion' => { major => $self->major_version } ] if $is_release;
 
   my @generated_files = qw( META.json Makefile.PL cpanfile );
-  my @on_release_files = ( qw/dist.ini Changes README.pod/, @generated_files );
+  my @on_release_files = ( qw/dist.ini Changes README.pod perlcritic.rc/, @generated_files );
   my @exclude_match = ( '^' . $meta->{name} . '-', @{$self->exclude_match} );
 
   my @plugins = (
@@ -335,7 +335,7 @@ Dist::Zilla::PluginBundle::MITHALDU - Dist::Zilla configuration the way MITHALDU
 
 =head1 VERSION
 
-version 1.190320
+version 1.190321
 
 =head1 SYNOPSIS
 
